==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-model/src/test/java/org/apache/streampipes/model/runtime/TestEventConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.model.runtime;

import org.junit.Test;

import java.util.Map;

import static junit.framework.TestCase.assertTrue;
import static org.junit.Assert.assertEquals;

public class TestEventConverter {

  @Test
  public void testSimpleEventConversion() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.simpleMap();
    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    Map<String, Object> convertedMap = new EventConverter(event).toMap();

    assertEquals(1, convertedMap.keySet().size());
    assertEquals(1, convertedMap.get("timestamp"));
  }

  @Test
  public void testNestedEventConversion() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.nestedMap();
    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    Map<String, Object> convertedMap = new EventConverter(event).toMap();

    assertEquals(2, convertedMap.keySet().size());
    assertEquals(1, convertedMap.get("timestamp"));
    assertTrue(convertedMap.containsKey("nested"));
    assertTrue(Map.class.isInstance(convertedMap.get("nested")));

    Map<String, Object> nestedMap = (Map<String, Object>) convertedMap.get("nested");
    assertTrue(nestedMap.containsKey("timestamp2"));
    assertEquals(2, nestedMap.get("timestamp2"));
  }
}

==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-model/src/test/java/org/apache/streampipes/model/runtime/TestEventConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.model.runtime;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.Map;

public class TestEventConverter {

  @Test
  public void testSimpleEventConversion() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.simpleMap();
    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    Map<String, Object> convertedMap = new EventConverter(event).toMap();

    Assertions.assertEquals(1,
                            convertedMap.keySet().size());
    Assertions.assertEquals(1, convertedMap.get("timestamp"));
  }

  @Test
  public void testNestedEventConversion() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.nestedMap();
    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    Map<String, Object> convertedMap = new EventConverter(event).toMap();

    Assertions.assertEquals(2,
                            convertedMap.keySet().size());
    Assertions.assertEquals(1, convertedMap.get("timestamp"));
    Assertions.assertTrue(convertedMap.containsKey("nested"));
    Assertions.assertTrue(Map.class.isInstance(convertedMap.get("nested")));

    Map<String, Object> nestedMap = (Map<String, Object>) convertedMap.get("nested");
    Assertions.assertTrue(nestedMap.containsKey("timestamp2"));
    Assertions.assertEquals(2, nestedMap.get("timestamp2"));
  }
}
